summaryrefslogtreecommitdiffstats
path: root/usr.sbin/ppp/bundle.c
diff options
context:
space:
mode:
authorbrian <brian@FreeBSD.org>2001-08-21 11:07:58 +0000
committerbrian <brian@FreeBSD.org>2001-08-21 11:07:58 +0000
commit2286423a9940558949a4146502f59590daf55499 (patch)
tree865da00fcc0a67c61cafad9286c0f73f1f3b5e61 /usr.sbin/ppp/bundle.c
parent637fbcbedbfa2fb5dd068cdf304bef2b5ab2bf33 (diff)
downloadFreeBSD-src-2286423a9940558949a4146502f59590daf55499.zip
FreeBSD-src-2286423a9940558949a4146502f59590daf55499.tar.gz
o Enable IFF_MULTICAST when first opening the tun device (and keep the flag
when we ioctl(TUNSIFINFO) under OpenBSD) o Don't bring the interface up immediately o Don't complain about unrecognised interface flags in ``show iface''.
Diffstat (limited to 'usr.sbin/ppp/bundle.c')
-rw-r--r--usr.sbin/ppp/bundle.c11
1 files changed, 2 insertions, 9 deletions
diff --git a/usr.sbin/ppp/bundle.c b/usr.sbin/ppp/bundle.c
index adf5257..6b76231 100644
--- a/usr.sbin/ppp/bundle.c
+++ b/usr.sbin/ppp/bundle.c
@@ -746,8 +746,8 @@ bundle_Create(const char *prefix, int type, int unit)
}
#ifdef TUNSIFMODE
- /* Make sure we're POINTOPOINT */
- iff = IFF_POINTOPOINT;
+ /* Make sure we're POINTOPOINT & IFF_MULTICAST */
+ iff = IFF_POINTOPOINT | IFF_MULTICAST;
if (ID0ioctl(bundle.dev.fd, TUNSIFMODE, &iff) < 0)
log_Printf(LogERROR, "bundle_Create: ioctl(TUNSIFMODE): %s\n",
strerror(errno));
@@ -784,13 +784,6 @@ bundle_Create(const char *prefix, int type, int unit)
#endif
#endif
- if (!iface_SetFlags(bundle.iface->name, IFF_UP)) {
- iface_Destroy(bundle.iface);
- bundle.iface = NULL;
- close(bundle.dev.fd);
- return NULL;
- }
-
log_Printf(LogPHASE, "Using interface: %s\n", ifname);
bundle.bandwidth = 0;
OpenPOWER on IntegriCloud